@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2021-09-14 19:42:28
+@LastEditTime: 2021-09-18 17:49:36
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -11,11 +11,13 @@ from seven_cloudapp_frame.models.order_base_model import *
 from seven_cloudapp_frame.models.stat_base_model import *
 
 
-class HorseracelampListHandler(TaoBaseHandler):
+class HorseracelampListHandler(ClientBaseHandler):
     """
     :description: 获取跑马灯奖品列表
     """
     @filter_check_params("act_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取跑马灯奖品列表
@@ -25,7 +27,7 @@ class HorseracelampListHandler(TaoBaseHandler):
         :return:
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
         module_id = int(self.get_param("module_id", -1))
         page_size = int(self.get_param("page_size", 10))
@@ -36,11 +38,13 @@ class HorseracelampListHandler(TaoBaseHandler):
         return self.response_json_success(order_base_model.get_horseracelamp_list(act_id, module_id, page_size))
 
 
-class SyncPayOrderHandler(TaoBaseHandler):
+class SyncPayOrderHandler(ClientBaseHandler):
     """
     :description: 同步淘宝支付订单给用户加资产
     """
     @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 同步淘宝支付订单给用户加资产
@@ -52,10 +56,10 @@ class SyncPayOrderHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
-        open_id = self.get_taobao_param().open_id
+        app_id = self.get_source_app_id()
+        open_id = self.get_param("open_id")
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         is_log = bool(self.get_param("is_log", False))
@@ -115,11 +119,13 @@ class SyncPayOrderHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class PrizeOrderListHandler(TaoBaseHandler):
+class PrizeOrderListHandler(ClientBaseHandler):
     """
     :description: 用户奖品订单列表
     """
     @filter_check_params("act_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 用户奖品订单列表
@@ -137,9 +143,9 @@ class PrizeOrderListHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        tb_user_id = self.get_param("tb_user_id")
+        user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
         order_status = self.get_param("order_status")
         create_date_start = self.get_param("create_date_start")
@@ -150,14 +156,16 @@ class PrizeOrderListHandler(TaoBaseHandler):
         page_size = int(self.get_param("page_size", 10))
 
         order_base_model = OrderBaseModel(context=self)
-        return self.response_json_success(order_base_model.get_prize_order_list(app_id, act_id, tb_user_id, user_open_id, "", "", "", "", "", order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=is_search_roster, is_cache=True))
+        return self.response_json_success(order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, "", "", "", "", "", order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=is_search_roster, is_cache=True))
 
 
-class PrizeRosterListHandler(TaoBaseHandler):
+class PrizeRosterListHandler(ClientBaseHandler):
     """
     :description: 用户中奖记录列表
     """
     @filter_check_params("act_id,tb_user_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 用户中奖记录列表
@@ -174,10 +182,10 @@ class PrizeRosterListHandler(TaoBaseHandler):
         :return PageInfo
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
-        open_id = self.get_taobao_param().open_id
+        app_id = self.get_source_app_id()
+        open_id = self.get_param("open_id")
         act_id = int(self.get_param("act_id", 0))
-        tb_user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         order_no = self.get_param("order_no")
         goods_type = int(self.get_param("goods_type", -1))
         prize_type = int(self.get_param("prize_type", -1))
@@ -188,14 +196,16 @@ class PrizeRosterListHandler(TaoBaseHandler):
         page_size = int(self.get_param("page_size", 20))
 
         order_base_model = OrderBaseModel(context=self)
-        return self.response_json_success(order_base_model.get_prize_roster_list(app_id, act_id, tb_user_id, open_id, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index))
+        return self.response_json_success(order_base_model.get_prize_roster_list(app_id, act_id, user_id, open_id, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index))
 
 
-class SubmitSkuHandler(TaoBaseHandler):
+class SubmitSkuHandler(ClientBaseHandler):
     """
     :description: 中奖记录选择SKU提交
     """
     @filter_check_params("user_prize_id,sku_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 提交SKU
@@ -205,8 +215,8 @@ class SubmitSkuHandler(TaoBaseHandler):
         :return 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
-        open_id = self.get_taobao_param().open_id
+        app_id = self.get_source_app_id()
+        open_id = self.get_param("open_id")
         user_prize_id = int(self.get_param("user_prize_id"))
         sku_name = self.get_param("sku_name")
         sku_id = self.get_param("sku_id")
@@ -227,11 +237,13 @@ class SubmitSkuHandler(TaoBaseHandler):
         return self.response_json_success()
 
 
-class SelectPrizeOrderHandler(TaoBaseHandler):
+class SelectPrizeOrderHandler(ClientBaseHandler):
     """
     :description: 中奖记录下单
     """
     @filter_check_params("act_id,tb_user_id,login_token,real_name,telephone")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :param act_id：活动标识
@@ -248,9 +260,9 @@ class SelectPrizeOrderHandler(TaoBaseHandler):
         :return
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        tb_user_id = self.get_param("tb_user_id")
+        user_id = self.get_user_id()
         login_token = self.get_param("login_token")
         prize_ids = self.get_param("prize_ids")
         real_name = self.get_param("real_name")
@@ -261,7 +273,7 @@ class SelectPrizeOrderHandler(TaoBaseHandler):
         street = self.get_param("street")
         address = self.get_param("address")
         order_base_model = OrderBaseModel(context=self)
-        invoke_result_data = order_base_model.select_prize_order(app_id, act_id, tb_user_id, login_token, prize_ids, real_name, telephone, province, city, county, street,address)
+        invoke_result_data = order_base_model.select_prize_order(app_id, act_id, user_id, login_token, prize_ids, real_name, telephone, province, city, county, street,address)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         else:
