@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-10 11:29:31
-@LastEditTime: 2021-09-14 19:43:34
+@LastEditTime: 2021-09-17 17:53:57
 @LastEditors: HuangJianYi
 @Description: 处理数据统计上报
 """
@@ -10,11 +10,13 @@ from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.stat_base_model import *
 
 
-class ShareReportHandler(TaoBaseHandler):
+class ShareReportHandler(ClientBaseHandler):
     """
     :description: 处理分享上报
     """
     @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理分享上报
@@ -26,9 +28,9 @@ class ShareReportHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         stat_base_model = StatBaseModel(context=self)
@@ -79,11 +81,13 @@ class ShareReportHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class InviteReportHandler(TaoBaseHandler):
+class InviteReportHandler(ClientBaseHandler):
     """
     :description: 处理邀请进入上报
     """
     @filter_check_params("act_id,tb_user_id,login_token")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理分享上报
@@ -95,9 +99,9 @@ class InviteReportHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         stat_base_model = StatBaseModel(context=self)
