@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-09-15 09:41:14
+@LastEditTime: 2021-09-22 17:01:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -16,11 +16,13 @@ from seven_cloudapp_frame.models.top_base_model import *
 from seven_cloudapp_frame.models.db_models.tao.tao_coupon_model import *
 
 
-class LoginHandler(TaoBaseHandler):
+class LoginHandler(ClientBaseHandler):
     """
     :description: 登录处理
     """
     @filter_check_params("act_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 登录处理
@@ -30,9 +32,9 @@ class LoginHandler(TaoBaseHandler):
         :return:
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
-        open_id = self.get_taobao_param().open_id
-        user_nick = self.get_taobao_param().user_nick
+        app_id = self.get_source_app_id()
+        open_id = self.get_param("open_id")
+        user_nick = self.get_param("user_nick")
         act_id = int(self.get_param("act_id", 0))
         module_id = int(self.get_param("module_id", 0))
         avatar = self.get_param("avatar")
@@ -45,6 +47,10 @@ class LoginHandler(TaoBaseHandler):
         if self.check_request_user(app_id, app_info_dict["current_limit_count"]):
             return self.response_json_error("current_limit", "登录失败")
 
+        invoke_result_data = self.business_process_executing(self.request_params)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+
         user_base_model = UserBaseModel(context=self)
         invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar)
         if invoke_result_data.success == False:
@@ -54,6 +60,17 @@ class LoginHandler(TaoBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
+    def business_process_executing(self, request_params):
+        """
+        :description: 执行前事件
+        :param request_params: 请求参数字典
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data.data = {}
+        return invoke_result_data
+
     def business_process_executed(self, invoke_result_data, app_id, act_id, module_id, open_id, user_nick, avatar):
         """
         :description: 执行后事件
@@ -77,11 +94,13 @@ class LoginHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class UpdateUserInfoHandler(TaoBaseHandler):
+class UpdateUserInfoHandler(ClientBaseHandler):
     """
     :description: 更新用户信息
     """
     @filter_check_params("act_id,tb_user_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 更新用户信息
@@ -93,11 +112,11 @@ class UpdateUserInfoHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
-        open_id = self.get_taobao_param().open_id
-        user_nick = self.get_taobao_param().user_nick
+        app_id = self.get_source_app_id()
+        open_id = self.get_param("open_id")
+        user_nick = self.get_param("user_nick")
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         avatar = self.get_param("avatar")
         is_member_before = int(self.get_param("is_member_before", -1))
         is_favor_before = int(self.get_param("is_favor_before", -1))
@@ -111,17 +130,19 @@ class UpdateUserInfoHandler(TaoBaseHandler):
             return self.response_json_success("更新成功")
 
 
-class CheckIsMemberHandler(TaoBaseHandler):
+class CheckIsMemberHandler(ClientBaseHandler):
     """
     :description: 校验是否是店铺会员
     """
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 校验是否是店铺会员
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         is_log = bool(self.get_param("is_log", False))
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
@@ -135,11 +156,13 @@ class CheckIsMemberHandler(TaoBaseHandler):
         return self.response_json_success(top_base_model.check_is_member(access_token, app_key, app_secret, is_log))
 
 
-class ApplyBlackUnbindHandler(TaoBaseHandler):
+class ApplyBlackUnbindHandler(ClientBaseHandler):
     """
     :description: 提交黑名单解封申请
     """
     @filter_check_params("act_id,tb_user_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 提交黑名单解封申请
@@ -149,10 +172,10 @@ class ApplyBlackUnbindHandler(TaoBaseHandler):
         :return 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
-        open_id = self.get_taobao_param().open_id
+        app_id = self.get_source_app_id()
+        open_id = self.get_param("open_id")
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         reason = self.get_param("reason", "误封号,申请解封")
 
         invoke_result_data = InvokeResultData()
@@ -164,11 +187,13 @@ class ApplyBlackUnbindHandler(TaoBaseHandler):
             return self.response_json_success()
 
 
-class GetCouponPrizeHandler(TaoBaseHandler):
+class GetCouponPrizeHandler(ClientBaseHandler):
     """
     :description: 领取淘宝优惠券
     """
     @filter_check_params("user_prize_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 领取淘宝优惠券（发奖接口）
@@ -176,8 +201,8 @@ class GetCouponPrizeHandler(TaoBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
-        open_id = self.get_taobao_param().open_id
+        app_id = self.get_source_app_id()
+        open_id = self.get_param("open_id")
         user_prize_id = int(self.get_param("user_prize_id", 0))
         is_log = bool(self.get_param("is_log", False))
         app_base_model = AppBaseModel(context=self)
@@ -223,11 +248,13 @@ class GetCouponPrizeHandler(TaoBaseHandler):
             return self.response_json_error("error", f"领取失败:{result}")
 
 
-class UserAssetListHandler(TaoBaseHandler):
+class UserAssetListHandler(ClientBaseHandler):
     """
     :description: 获取用户资产列表
     """
     @filter_check_params("act_id,tb_user_id")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取用户资产列表
@@ -237,20 +264,22 @@ class UserAssetListHandler(TaoBaseHandler):
         :return list
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         asset_type = int(self.get_param("asset_type", 0))
 
         asset_base_model = AssetBaseModel(context=self)
         return self.response_json_success(asset_base_model.get_user_asset_list(app_id, act_id, user_id, asset_type))
 
 
-class AssetLogListHandler(TaoBaseHandler):
+class AssetLogListHandler(ClientBaseHandler):
     """
     :description: 资产流水记录
     """
     @filter_check_params("act_id,tb_user_id,asset_type")
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 资产流水记录
@@ -263,10 +292,10 @@ class AssetLogListHandler(TaoBaseHandler):
         :return list
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
-        open_id = self.get_taobao_param().open_id
+        app_id = self.get_source_app_id()
+        open_id = self.get_param("open_id")
         act_id = int(self.get_param("act_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
         asset_type = int(self.get_param("asset_type", 0))
@@ -276,17 +305,19 @@ class AssetLogListHandler(TaoBaseHandler):
         return self.response_json_success(asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, "", "", "", open_id, 0, ""))
 
 
-class GetJoinMemberUrlHandler(TaoBaseHandler):
+class GetJoinMemberUrlHandler(ClientBaseHandler):
     """
     :description: 获取加入会员地址
     """
+    @filter_check_head_sign()
+    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取加入会员地址
         :return
         :last_editors: HuangJianYi
         """
-        app_id = self.get_taobao_param().source_app_id
+        app_id = self.get_source_app_id()
         is_log = bool(self.get_param("is_log",False))
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
