@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-09-28 10:44:57
+@LastEditTime: 2021-09-30 17:37:20
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -333,7 +333,7 @@ class FrameBaseHandler(BaseApiHandler):
 class ClientBaseHandler(FrameBaseHandler):
 
     """
-    :description: handler基类
+    :description: 客户端handler基类
     """
 
     device_info_dict = {}  # 头部参数
@@ -374,31 +374,29 @@ class ClientBaseHandler(FrameBaseHandler):
                 self.add_request_user(str(dict_param["app_id"]), str(dict_param["open_id"]))
 
         except Exception as ex:
-            self.logging_link_error("【handler基类】" + str(ex))
+            self.logging_link_error("【客户端handler基类】" + str(ex))
 
     def get_user_nick(self):
         """
         :description: 获取用户昵称
-        :param self
+        淘宝小程序 如果要在test和online环境指定账号打开后台测试，需由前端写死传入
         :return str
         :last_editors: HuangJianYi
         """
         user_nick = self.get_param("user_nick")
+        #淘宝小程序 source_app_id在本地环境返回空；在test和online环境返回后端模板id，无论在IDE还是千牛端
         if self.get_param("source_app_id") == "":
-            #前端（在IDE上返回前端模板id，在千牛上返回正确的id）
             user_nick = config.get_value("test_user_nick")
         return user_nick
 
     def get_open_id(self):
         """
         :description: 获取open_id
-        :param self
         :return str
         :last_editors: HuangJianYi
         """
         open_id = self.get_param("open_id")
         if self.get_param("source_app_id") == "":
-            #前端（在IDE上返回前端模板id，在千牛上返回正确的id）
             open_id = config.get_value("test_open_id")
         return open_id
 
@@ -417,13 +415,12 @@ class ClientBaseHandler(FrameBaseHandler):
     def get_source_app_id(self):
         """
         :description: 获取source_app_id(客户端使用)
-        :param self
         :return str
         :last_editors: HuangJianYi
         """
         source_app_id = self.get_param("source_app_id")
+        #淘宝小程序 在IDE上返回前端模板id，无论哪个环境；在千牛端上返回正确的小程序id
         if source_app_id == config.get_value("client_template_id"):
-            #前端（在IDE上返回前端模板id，在千牛上返回正确的id）
             source_app_id = config.get_value("test_source_app_id")
         return source_app_id
 
