@@ -12,7 +12,7 @@ from seven_cloudapp_frame.models.act_base_model import *
 from seven_cloudapp_frame.models.seven_model import PageInfo
 
 
-class ActTypeListHandler(TaoBaseHandler):
+class ActTypeListHandler(ClientBaseHandler):
     """
     :description: 获取活动类型列表
     """
@@ -37,7 +37,7 @@ class ActTypeListHandler(TaoBaseHandler):
         return self.response_json_success(new_list)
 
 
-class AddActInfoHandler(TaoBaseHandler):
+class AddActInfoHandler(ClientBaseHandler):
     """
     :description: 添加活动信息
     """
@@ -70,7 +70,7 @@ class AddActInfoHandler(TaoBaseHandler):
         return self.response_json_success(invoke_result_data.data.id)
 
 
-class UpdateActInfoHandler(TaoBaseHandler):
+class UpdateActInfoHandler(ClientBaseHandler):
     """
     :description: 修改活动信息
     """
@@ -147,7 +147,7 @@ class UpdateActInfoHandler(TaoBaseHandler):
         return self.response_json_success()
 
 
-class ActInfoListHandler(TaoBaseHandler):
+class ActInfoListHandler(ClientBaseHandler):
     """
     :description: 活动列表
     """
@@ -179,7 +179,7 @@ class ActInfoListHandler(TaoBaseHandler):
         return self.response_json_success(page_info)
 
 
-class ActInfoHandler(TaoBaseHandler):
+class ActInfoHandler(ClientBaseHandler):
     """
     :description: 获取活动信息
     """
@@ -208,7 +208,7 @@ class ActInfoHandler(TaoBaseHandler):
         return self.response_json_success(act_info_dict)
 
 
-class DeleteActInfoHandler(TaoBaseHandler):
+class DeleteActInfoHandler(ClientBaseHandler):
     """
     :description: 删除活动
     """
@@ -231,7 +231,7 @@ class DeleteActInfoHandler(TaoBaseHandler):
         return self.response_json_success()
 
 
-class ReviewActInfoHandler(TaoBaseHandler):
+class ReviewActInfoHandler(ClientBaseHandler):
     """
     :description: 还原活动
     """
@@ -255,7 +255,7 @@ class ReviewActInfoHandler(TaoBaseHandler):
         return self.response_json_success()
 
 
-class ReleaseActInfoHandler(TaoBaseHandler):
+class ReleaseActInfoHandler(ClientBaseHandler):
     """
     :description: 上下架活动
     """
@@ -280,7 +280,7 @@ class ReleaseActInfoHandler(TaoBaseHandler):
         self.response_json_success()
 
 
-class CreateActQrCodeHandler(TaoBaseHandler):
+class CreateActQrCodeHandler(ClientBaseHandler):
     """
     :description: 创建活动二维码
     """
@@ -298,7 +298,7 @@ class CreateActQrCodeHandler(TaoBaseHandler):
         return self.response_json_success(f"data:image/jpeg;base64,{img_base64}")
 
 
-class NextProgressHandler(TaoBaseHandler):
+class NextProgressHandler(ClientBaseHandler):
     """
     :description: 下一步配置
     """
