@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-08-03 10:11:39
-@LastEditTime: 2021-09-14 19:46:33
+@LastEditTime: 2021-09-17 15:11:53
 @LastEditors: HuangJianYi
 :description: 商品相关
 """
@@ -11,7 +11,7 @@ from seven_cloudapp_frame.models.top_base_model import *
 from seven_cloudapp_frame.models.goods_base_model import *
 
 
-class GoodsListHandler(TaoBaseHandler):
+class GoodsListHandler(ClientBaseHandler):
     """
     :description: 商品列表（获取当前会话用户出售中的商品列表）
     """
@@ -26,7 +26,7 @@ class GoodsListHandler(TaoBaseHandler):
         :return: 列表
         :last_editors: HuangJianYi
         """
-        access_token = self.get_taobao_param().access_token
+        access_token = self.get_param("access_token")
         goods_name = self.get_param("goods_name")
         order_tag = self.get_param("order_tag", "list_time")
         order_by = self.get_param("order_by", "desc")
@@ -42,7 +42,7 @@ class GoodsListHandler(TaoBaseHandler):
         return self.response_json_success(invoke_result_data.data)
 
 
-class GoodsListByGoodsIDHandler(TaoBaseHandler):
+class GoodsListByGoodsIDHandler(ClientBaseHandler):
     """
     :description: 根据商品ID串获取商品列表
     """
@@ -54,7 +54,7 @@ class GoodsListByGoodsIDHandler(TaoBaseHandler):
         :return: list
         :last_editors: HuangJianYi
         """
-        access_token = self.get_taobao_param().access_token
+        access_token = self.get_param("access_token")
         goods_ids = self.get_param("goods_ids")
         is_log = bool(self.get_param("is_log",False))
 
@@ -66,7 +66,7 @@ class GoodsListByGoodsIDHandler(TaoBaseHandler):
         return self.response_json_success(invoke_result_data.data)
 
 
-class GoodsInfoHandler(TaoBaseHandler):
+class GoodsInfoHandler(ClientBaseHandler):
     """
     :description: 获取商品信息
     """
@@ -78,7 +78,7 @@ class GoodsInfoHandler(TaoBaseHandler):
         :return: 商品信息
         :last_editors: HuangJianYi
         """
-        access_token = self.get_taobao_param().access_token
+        access_token = self.get_param("access_token")
         goods_id = self.get_param("goods_id")
         is_log = bool(self.get_param("is_log",False))
 
@@ -90,7 +90,7 @@ class GoodsInfoHandler(TaoBaseHandler):
         return self.response_json_success(invoke_result_data.data)
 
 
-class BenefitDetailHandler(TaoBaseHandler):
+class BenefitDetailHandler(ClientBaseHandler):
     """
     :description: 获取优惠券详情信息
     """
@@ -101,7 +101,7 @@ class BenefitDetailHandler(TaoBaseHandler):
         :return: dict
         :last_editors: HuangJianYi
         """
-        access_token = self.get_taobao_param().access_token
+        access_token = self.get_param("access_token")
         right_ename = self.get_param("right_ename")
         is_log = bool(self.get_param("is_log",False))
 
@@ -113,7 +113,7 @@ class BenefitDetailHandler(TaoBaseHandler):
         return self.response_json_success(invoke_result_data.data)
 
 
-class InventoryGoodsListHandler(TaoBaseHandler):
+class InventoryGoodsListHandler(ClientBaseHandler):
     """
     :description: 导入商品列表（获取当前用户作为卖家的仓库中的商品列表）
     """
@@ -128,7 +128,7 @@ class InventoryGoodsListHandler(TaoBaseHandler):
         :return: 列表
         :last_editors: HuangJianYi
         """
-        access_token = self.get_taobao_param().access_token
+        access_token = self.get_param("access_token")
         goods_name = self.get_param("goods_name")
         order_tag = self.get_param("order_tag", "list_time")
         order_by = self.get_param("order_by", "desc")
@@ -142,7 +142,7 @@ class InventoryGoodsListHandler(TaoBaseHandler):
         return self.response_json_success(invoke_result_data.data)
 
 
-class SpecialGoodsListHandler(TaoBaseHandler):
+class SpecialGoodsListHandler(ClientBaseHandler):
     """
     :description: 专属下单商品列表
     """
@@ -162,7 +162,7 @@ class SpecialGoodsListHandler(TaoBaseHandler):
         page_size = int(self.get_param("page_size", 20))
         goods_name = self.get_param("goods_name")
         is_log = self.get_param("is_log",False)
-        access_token = self.get_taobao_param().access_token
+        access_token = self.get_param("access_token")
 
         goods_base_model = GoodsBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
@@ -172,7 +172,7 @@ class SpecialGoodsListHandler(TaoBaseHandler):
         return self.response_json_success(invoke_result_data.data)
 
 
-class BindSpecialGoodsHandler(TaoBaseHandler):
+class BindSpecialGoodsHandler(ClientBaseHandler):
     """
     :description: 专属下单商品绑定(单个商品)
     """
@@ -186,7 +186,7 @@ class BindSpecialGoodsHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        access_token = self.get_taobao_param().access_token
+        access_token = self.get_param("access_token")
         goods_id = self.get_param("goods_id")
         goods_name = self.get_param("goods_name")
         is_log = self.get_param("is_log",False)
