@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 11:03:56
-@LastEditTime: 2021-09-14 19:46:40
+@LastEditTime: 2021-09-17 17:26:24
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -12,7 +12,7 @@ from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.enum import *
 
 
-class SaveIpInfoHandler(TaoBaseHandler):
+class SaveIpInfoHandler(ClientBaseHandler):
     """
     :description: 保存IP信息
     """
@@ -46,14 +46,14 @@ class SaveIpInfoHandler(TaoBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
             # 记录日志
-            self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveIpInfoHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_taobao_param().open_id, self.get_taobao_param().user_nick)
+            self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SaveIpInfoHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
         else:
-            self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveIpInfoHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_taobao_param().open_id, self.get_taobao_param().user_nick)
+            self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SaveIpInfoHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
 
         self.response_json_success(invoke_result_data.data["new"].id)
 
 
-class IpInfoListHandler(TaoBaseHandler):
+class IpInfoListHandler(ClientBaseHandler):
     """
     :description: 获取ip列表
     """
@@ -76,7 +76,7 @@ class IpInfoListHandler(TaoBaseHandler):
         self.response_json_success(IpBaseModel(context=self).get_ip_info_list(app_id, act_id, page_size, page_index,is_cache=False))
 
 
-class DeleteIpInfoHandler(TaoBaseHandler):
+class DeleteIpInfoHandler(ClientBaseHandler):
     """
     :description: 删除ip
     """
@@ -104,7 +104,7 @@ class DeleteIpInfoHandler(TaoBaseHandler):
         self.response_json_success()
 
 
-class ReleaseIpInfoHandler(TaoBaseHandler):
+class ReleaseIpInfoHandler(ClientBaseHandler):
     """
     :description: 上下架ip
     """
