@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-30 15:46:34
-@LastEditTime: 2021-09-14 19:46:46
+@LastEditTime: 2021-09-17 15:12:40
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -16,7 +16,7 @@ from seven_cloudapp_frame.models.db_models.launch.launch_goods_model import *
 from seven_cloudapp_frame.models.db_models.price.price_gear_model import *
 
 
-class InitLaunchGoodsHandler(TaoBaseHandler):
+class InitLaunchGoodsHandler(ClientBaseHandler):
     """
     :description: 初始化商品投放
     """
@@ -44,7 +44,7 @@ class InitLaunchGoodsHandler(TaoBaseHandler):
         return self.response_json_success(invoke_result_data.data)
 
 
-class ResetLaunchGoodsHandler(TaoBaseHandler):
+class ResetLaunchGoodsHandler(ClientBaseHandler):
     """
     :description: 重置商品投放 删除已投放的记录并将活动投放状态改为未投放
     """
@@ -66,7 +66,7 @@ class ResetLaunchGoodsHandler(TaoBaseHandler):
         self.response_json_success()
 
 
-class InitLaunchGoodsCallBackHandler(TaoBaseHandler):
+class InitLaunchGoodsCallBackHandler(ClientBaseHandler):
     """
     :description: 初始化投放商品回调接口
     """
@@ -92,7 +92,7 @@ class InitLaunchGoodsCallBackHandler(TaoBaseHandler):
         self.response_json_success()
 
 
-class UpdateLaunchGoodsStatusHandler(TaoBaseHandler):
+class UpdateLaunchGoodsStatusHandler(ClientBaseHandler):
     """
     :description: 更改投放商品的状态
     """
@@ -115,7 +115,7 @@ class UpdateLaunchGoodsStatusHandler(TaoBaseHandler):
         self.response_json_success()
 
 
-class LaunchGoodsListHandler(TaoBaseHandler):
+class LaunchGoodsListHandler(ClientBaseHandler):
     """
     :description: 投放商品列表
     """
@@ -136,13 +136,13 @@ class LaunchGoodsListHandler(TaoBaseHandler):
         page_size = int(self.get_param("page_size", 20))
         launch_base_model = LaunchBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = launch_base_model.get_launch_goods_list(app_id, act_id, page_size, page_index, self.get_taobao_param().access_token, app_key, app_secret)
+        invoke_result_data = launch_base_model.get_launch_goods_list(app_id, act_id, page_size, page_index, self.get_param("access_token"), app_key, app_secret)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
 
-class AsyncLaunchGoodsHandler(TaoBaseHandler):
+class AsyncLaunchGoodsHandler(ClientBaseHandler):
     """
     :description: 同步投放商品（小程序投放-商品绑定/解绑）
     """
@@ -163,7 +163,7 @@ class AsyncLaunchGoodsHandler(TaoBaseHandler):
         online_url = self.get_online_url(act_id, app_id, module_id)
         launch_base_model = LaunchBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = launch_base_model.async_launch_goods(app_id, act_id, online_url, self.get_taobao_param().access_token, app_key,app_secret)
+        invoke_result_data = launch_base_model.async_launch_goods(app_id, act_id, online_url, self.get_param("access_token"), app_key, app_secret)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
\ No newline at end of file
