@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2021-09-14 19:47:20
+@LastEditTime: 2021-09-27 11:25:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -12,7 +12,7 @@ from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.order_base_model import *
 
 
-class PayOrderListHandler(TaoBaseHandler):
+class PayOrderListHandler(ClientBaseHandler):
     """
     :description: 用户购买订单列表
     """
@@ -34,7 +34,7 @@ class PayOrderListHandler(TaoBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
-        tb_user_id = self.get_param("tb_user_id")
+        user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
         nick_name = self.get_param("nick_name")
         pay_date_start = self.get_param("pay_date_start")
@@ -43,10 +43,10 @@ class PayOrderListHandler(TaoBaseHandler):
         page_size = int(self.get_param("page_size", 20))
 
         order_base_model = OrderBaseModel(context=self)
-        return self.response_json_success(order_base_model.get_tao_pay_order_list(app_id, act_id, tb_user_id, user_open_id, nick_name, pay_date_start, pay_date_end, page_size, page_index))
+        return self.response_json_success(order_base_model.get_tao_pay_order_list(app_id, act_id, user_id, user_open_id, nick_name, pay_date_start, pay_date_end, page_size, page_index))
 
 
-class PrizeOrderListHandler(TaoBaseHandler):
+class PrizeOrderListHandler(ClientBaseHandler):
     """
     :description: 用户奖品订单列表
     """
@@ -56,7 +56,7 @@ class PrizeOrderListHandler(TaoBaseHandler):
         :description: 用户奖品订单列表
         :param app_id：应用标识
         :param act_id：活动标识
-        :param tb_user_id：用户标识
+        :param user_id：用户标识
         :param user_open_id：open_id
         :param order_no：订单号
         :param nick_name：用户昵称
@@ -75,7 +75,7 @@ class PrizeOrderListHandler(TaoBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
-        tb_user_id = self.get_param("tb_user_id")
+        user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
         nick_name = self.get_param("nick_name")
         order_no = self.get_param("order_no")
@@ -92,10 +92,10 @@ class PrizeOrderListHandler(TaoBaseHandler):
         page_size = int(self.get_param("page_size", 20))
 
         order_base_model = OrderBaseModel(context=self)
-        return self.response_json_success(order_base_model.get_prize_order_list(app_id, act_id, tb_user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=is_search_roster, is_cache=False))
+        return self.response_json_success(order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=is_search_roster, is_cache=False))
 
 
-class PrizeRosterListHandler(TaoBaseHandler):
+class PrizeRosterListHandler(ClientBaseHandler):
     """
     :description: 用户中奖记录列表
     """
@@ -125,7 +125,7 @@ class PrizeRosterListHandler(TaoBaseHandler):
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
         module_id = int(self.get_param("module_id", 0))
-        user_id = int(self.get_param("tb_user_id", 0))
+        user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
         order_no = self.get_param("order_no")
         user_nick = self.get_param("nick_name")
@@ -150,7 +150,7 @@ class PrizeRosterListHandler(TaoBaseHandler):
             params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
             order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         order_base_model = OrderBaseModel(context=self)
-        return self.response_json_success(order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end,order_by=order_by, condition=condition,params=params))
+        return self.response_json_success(order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end,order_by=order_by, condition=condition,params=params,is_cache=False))
 
     def business_process_executing(self,request_params):
         """
@@ -164,7 +164,7 @@ class PrizeRosterListHandler(TaoBaseHandler):
         return invoke_result_data
 
 
-class UpdatePrizeOrderSellerRemarkHandler(TaoBaseHandler):
+class UpdatePrizeOrderSellerRemarkHandler(ClientBaseHandler):
     """
     :description: 更新奖品订单卖家备注
     """
@@ -188,7 +188,7 @@ class UpdatePrizeOrderSellerRemarkHandler(TaoBaseHandler):
         self.response_json_success()
 
 
-class UpdatePrizeOrderStatusHandler(TaoBaseHandler):
+class UpdatePrizeOrderStatusHandler(ClientBaseHandler):
     """
     :description: 更新用户奖品订单状态
     """
@@ -217,7 +217,7 @@ class UpdatePrizeOrderStatusHandler(TaoBaseHandler):
         self.response_json_success()
 
 
-class ImportPrizeOrderHandler(TaoBaseHandler):
+class ImportPrizeOrderHandler(ClientBaseHandler):
     """
     :description: 导入奖品订单进行发货
     """
@@ -226,7 +226,8 @@ class ImportPrizeOrderHandler(TaoBaseHandler):
         """
         :description: 导入奖品订单进行发货
         :param app_id：应用标识
-        :param content：base64加密后的excel内容
+        :param content_type：内容类型 1-base64字符串内容 2-json字符串内容
+        :param content：字符串内容
         :param act_id：活动标识
         :param ref_head_name：关联表头名称，可不传
         :return 
@@ -235,16 +236,17 @@ class ImportPrizeOrderHandler(TaoBaseHandler):
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
         content = self.get_param("content")
+        content_type = int(self.get_param("content_type", 1))
         ref_head_name = self.get_param("ref_head_name", "小程序订单号")
 
         order_base_model = OrderBaseModel(context=self)
-        invoke_result_data = order_base_model.import_prize_order(app_id, act_id, content, ref_head_name)
+        invoke_result_data = order_base_model.import_prize_order(app_id, act_id, content_type, content, ref_head_name)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.response_json_success()
 
 
-class PrizeOrderExportHandler(TaoBaseHandler):
+class PrizeOrderExportHandler(ClientBaseHandler):
     """
     :description: 导出奖品订单列表
     """
@@ -254,7 +256,7 @@ class PrizeOrderExportHandler(TaoBaseHandler):
         :description: 导出奖品订单列表
         :param app_id：应用标识
         :param act_id：活动标识
-        :param user_id：用户标识
+        :param tb_user_id：用户标识
         :param open_id：open_id
         :param order_no：订单号
         :param nick_name：用户昵称
@@ -271,7 +273,7 @@ class PrizeOrderExportHandler(TaoBaseHandler):
         """
         app_id = self.get_app_id()
         act_id = int(self.get_param("act_id", 0))
-        tb_user_id = self.get_param("tb_user_id")
+        user_id = self.get_user_id()
         user_open_id = self.get_param("user_open_id")
         nick_name = self.get_param("nick_name")
         order_no = self.get_param("order_no")
@@ -287,7 +289,7 @@ class PrizeOrderExportHandler(TaoBaseHandler):
         page_size = int(self.get_param("page_size", 20))
 
         order_base_model = OrderBaseModel(context=self)
-        prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, tb_user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=True, is_cache=False).data
+        prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=True, is_cache=False).data
         result_data = self.business_process_executed(prize_order_list_dict, self.request_params)
         resource_path = OSS2Helper.export_excel(result_data)
         return self.response_json_success(resource_path)
@@ -333,7 +335,7 @@ class PrizeOrderExportHandler(TaoBaseHandler):
         return result_data
 
 
-class PrizeRosterExportHandler(TaoBaseHandler):
+class PrizeRosterExportHandler(ClientBaseHandler):
     """
     :description: 导出用户中奖记录列表
     """
@@ -366,7 +368,7 @@ class PrizeRosterExportHandler(TaoBaseHandler):
         act_id = int(self.get_param("act_id", 0))
         module_id = int(self.get_param("module_id", 0))
         order_no = self.get_param("order_no")
-        user_id = int(self.get_param("tb_user_id",0))
+        user_id = self.get_user_id()
         user_nick = self.get_param("nick_name")
         user_open_id = self.get_param("user_open_id")
         is_order = self.get_param("is_order")
