@@ -12,7 +12,7 @@ from seven_cloudapp_frame.models.enum import *
 from seven_cloudapp_frame.models.db_models.price.price_gear_model import *
 
 
-class SavePriceGearHandler(TaoBaseHandler):
+class SavePriceGearHandler(ClientBaseHandler):
     """
     :description: 保存价格档位信息
     """
@@ -50,14 +50,14 @@ class SavePriceGearHandler(TaoBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
             # 记录日志
-            self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SavePriceGearHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_taobao_param().open_id, self.get_taobao_param().user_nick)
+            self.create_operation_log(OperationType.add.value, invoke_result_data.data["new"].__str__(), "SavePriceGearHandler", None, self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
         else:
-            self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SavePriceGearHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_taobao_param().open_id, self.get_taobao_param().user_nick)
+            self.create_operation_log(OperationType.update.value, invoke_result_data.data["new"].__str__(), "SavePriceGearHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]), self.get_open_id(), self.get_user_nick())
 
         self.response_json_success(invoke_result_data.data["new"].id)
 
 
-class PriceGearListHandler(TaoBaseHandler):
+class PriceGearListHandler(ClientBaseHandler):
     """
     :description: 获取价格档位列表
     """
@@ -82,7 +82,7 @@ class PriceGearListHandler(TaoBaseHandler):
         self.response_json_success(PriceBaseModel(context=self).get_price_gear_list(app_id, act_id, page_size, page_index,is_del=is_del,is_cache=False))
 
 
-class DeletePriceGearHandler(TaoBaseHandler):
+class DeletePriceGearHandler(ClientBaseHandler):
     """
     :description: 删除档位
     """
@@ -108,7 +108,7 @@ class DeletePriceGearHandler(TaoBaseHandler):
         self.response_json_success()
 
 
-class ReviewPriceGearHandler(TaoBaseHandler):
+class ReviewPriceGearHandler(ClientBaseHandler):
     """
     :description: 恢复价格档位
     """
@@ -134,7 +134,7 @@ class ReviewPriceGearHandler(TaoBaseHandler):
         self.response_json_success()
 
 
-class CheckPriceGearHandler(TaoBaseHandler):
+class CheckPriceGearHandler(ClientBaseHandler):
     """
     :description: 验证价格档位
     """
