@@ -13,7 +13,7 @@ from seven_cloudapp_frame.models.enum import *
 from seven_cloudapp_frame.models.db_models.task.task_info_model import *
 
 
-class TaskInfoListHandler(TaoBaseHandler):
+class TaskInfoListHandler(ClientBaseHandler):
     """
     :description: 获取任务列表
     """
@@ -36,7 +36,7 @@ class TaskInfoListHandler(TaoBaseHandler):
         return self.response_json_success(task_base_model.get_task_info_dict_list(app_id, act_id, module_id,is_release,False))
 
 
-class SaveTaskInfoHandler(TaoBaseHandler):
+class SaveTaskInfoHandler(ClientBaseHandler):
     """
     :description 保存任务
     """
