@@ -11,7 +11,7 @@ from seven_cloudapp_frame.handlers.frame_base import *
 from seven_cloudapp_frame.models.theme_base_model import *
 
 
-class ThemeInfoListHandler(TaoBaseHandler):
+class ThemeInfoListHandler(ClientBaseHandler):
     """
     :description: 主题列表
     """
@@ -27,7 +27,7 @@ class ThemeInfoListHandler(TaoBaseHandler):
         self.response_json_success(theme_base_model.get_theme_list(app_id,is_cache=False))
 
 
-class SkinInfoListHandler(TaoBaseHandler):
+class SkinInfoListHandler(ClientBaseHandler):
     """
     :description: 皮肤列表
     """
@@ -44,7 +44,7 @@ class SkinInfoListHandler(TaoBaseHandler):
         self.response_json_success(theme_base_model.get_skin_list(theme_id,is_cache=False))
 
 
-class UpdateThemeHandler(TaoBaseHandler):
+class UpdateThemeHandler(ClientBaseHandler):
     """
     :description: 更新活动主题和皮肤
     """
