@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-30 09:22:51
-@LastEditTime: 2021-09-27 16:22:23
+@LastEditTime: 2021-09-29 11:51:17
 @LastEditors: HuangJianYi
 @Description: 排队系统帮助类
 """
@@ -13,7 +13,7 @@ from seven_cloudapp_frame.libs.customize.seven_helper import *
 
 class QueueUpHelper:
     """
-    :description: 排队系统帮助类 提供加入排队、退出排队、查询单个排队情况、批量查询排队情况、更新可操作时间、签到等功能
+    :description: 排队系统帮助类 提供获取小程序总排队人数、获取用户当前排队数、获取用户正在办理中的队列信息、加入排队、退出排队、查询单个排队情况、批量查询某用户排队情况(只包含已排队的信息)、批量查询某用户排队情况(包含已排队和未排队的信息)、更新可操作时间、签到等功能
     踢人规则：第一个在办理中，第二个用户的过期时间=第一个结束时间+8*1，第三个=第一个结束时间+8*2，以此类推；第一个没在办理中，第一个过期时间是8*1，第二个是8*2，第三个是8*3，以此类推；
     """
     logger_error = Logger.get_logger_by_name("log_error")
@@ -287,7 +287,7 @@ class QueueUpHelper:
     @classmethod
     def pop_by_queue_name(self, app_id, queue_name):
         """
-        :description: 过期用户退出队列
+        :description: 将过期用户从队列中退出
         :param app_id：应用标识
         :param queue_name：队列名称
         :return: 
@@ -422,7 +422,7 @@ class QueueUpHelper:
     @classmethod
     def muti_user_query(self, app_id, user_id):
         """
-        :description: 批量查询某用户排队情况 只包含已排队的信息
+        :description: 批量查询某用户排队情况(只包含已排队的信息)
         :param app_id：应用标识
         :param user_id：用户标识
         :return: 
@@ -451,7 +451,7 @@ class QueueUpHelper:
     @classmethod
     def muti_queue_query(self, app_id, queue_name_list, user_id):
         """
-        :description: 批量查询排队情况 包含已排队和未排队的信息
+        :description: 批量查询某用户排队情况(包含已排队和未排队的信息)
         :param app_id：应用标识
         :param queue_name_list：查询队列集合
         :param user_id：用户标识
@@ -519,7 +519,7 @@ class QueueUpHelper:
     @classmethod
     def sign(self, app_id, queue_name, user_id, pop_other_queue=True):
         """
-        :description: 签到操作（证明排队的人做出应答，开始办理业务，更新开始操作时间并且将当前用户在其他队列中踢掉）
+        :description: 签到操作（证明排队的人做出应答，开始办理业务，更新开始操作时间）
         :param app_id：应用标识
         :param queue_name：队列名称
         :param user_id：用户标识
