@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-09-22 16:00:14
+@LastEditTime: 2021-09-30 18:12:41
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -234,16 +234,16 @@ class SevenHelper:
         return False
 
     @classmethod
-    def get_first_ip(self):
+    def get_first_ip(self,remote_ip):
         """
         :description: 获取第一个IP
+        :param remote_ip: ip串
         :return:
         """
-        ip = self.get_remote_ip()
-        if ip and "," in ip:
-            return ip.split(",")[0]
+        if remote_ip and "," in remote_ip:
+            return remote_ip.split(",")[0]
         else:
-            return ip
+            return remote_ip
 
     @classmethod
     def to_file_size(self, size):
@@ -337,7 +337,7 @@ class SevenHelper:
         :return: int（2020050612）
         :last_editors: HuangJianYi
         """
-        return self.get_now_int(fmt='%Y%m%d%H')
+        return self.get_now_int(hours=hours, fmt='%Y%m%d%H')
 
     @classmethod
     def get_now_day_int(self, hours=0):
@@ -347,7 +347,7 @@ class SevenHelper:
         :return: int（20200506）
         :last_editors: HuangJianYi
         """
-        return self.get_now_int(fmt='%Y%m%d')
+        return self.get_now_int(hours=hours, fmt='%Y%m%d')
 
     @classmethod
     def get_now_month_int(self, hours=0):
@@ -357,7 +357,7 @@ class SevenHelper:
         :return: int（202005）
         :last_editors: HuangJianYi
         """
-        return self.get_now_int(fmt='%Y%m')
+        return self.get_now_int(hours=hours,fmt='%Y%m')
 
     @classmethod
     def get_date_list(self, start_date, end_date):
