@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2021-08-26 10:28:51
+@LastEditTime: 2021-09-29 16:02:41
 @LastEditors: HuangJianYi
 :Description: 数据库基础操作类
 """
@@ -24,7 +24,7 @@ class CacheModel(BaseModel):
         """
         super(CacheModel,self).__init__(model_class, sub_table)
 
-    def _get_dependency_key(self, dependency_key=''):
+    def __get_dependency_key(self, dependency_key=''):
         """
         :Description: 获取依赖建
         :param dependencyKey: 依赖键
@@ -35,7 +35,7 @@ class CacheModel(BaseModel):
             dependency_key = "dependency_" + self.table_name.lower()
         return dependency_key
 
-    def _get_cache_key(self, where='', group_by='', order_by='', limit='', params=None):
+    def __get_cache_key(self, where='', group_by='', order_by='', limit='', params=None):
         """
         :Description: 获取缓存key
         :param where: 数据库查询条件语句
@@ -56,7 +56,7 @@ class CacheModel(BaseModel):
         cache_key = str(where + "_" + group_by + "_" + order_by + "_" + limit + params_str).replace(" ", "").lower()
         return CryptoHelper.md5_encrypt(cache_key)
         
-    def _get_dependency_cache_key(self, dependency_key, cache_key):
+    def __get_dependency_cache_key(self, dependency_key, cache_key):
         """
         :Description: 获取依赖缓存key
         :param dependency_key: 依赖键
@@ -66,7 +66,7 @@ class CacheModel(BaseModel):
         """
         return CryptoHelper.md5_encrypt(dependency_key+cache_key)
 
-    def _get_dependency_cache(self, dependency_key, cache_key):
+    def __get_dependency_cache(self, dependency_key, cache_key):
         """
         :Description: 获取依赖缓存值
         :param dependency_key: 依赖键
@@ -74,8 +74,8 @@ class CacheModel(BaseModel):
         :return: 依赖缓存值
         :last_editors: HuangJianYi
         """
-        dependency_cache_key = self._get_dependency_cache_key(dependency_key,cache_key)
-        redis_init = self._redis_init()
+        dependency_cache_key = self.__get_dependency_cache_key(dependency_key,cache_key)
+        redis_init = self.__redis_init()
         dependency_date_value = redis_init.get(dependency_key)
         if not dependency_date_value:
             redis_init.delete(dependency_cache_key)
@@ -103,7 +103,7 @@ class CacheModel(BaseModel):
             cache_data = json.loads(cache_data)
             return cache_data
                              
-    def _set_dependency_cache(self, dependency_key, cache_key,value, cache_expire):
+    def __set_dependency_cache(self, dependency_key, cache_key,value, cache_expire):
         """
         :Description: 获取依赖缓存值
         :param dependency_key: 依赖键
@@ -114,15 +114,15 @@ class CacheModel(BaseModel):
         """
         if not value:
             return
-        redis_init = self._redis_init()
+        redis_init = self.__redis_init()
         dependency_date_value = redis_init.get(dependency_key)
         if not dependency_date_value:
             redis_init.set(dependency_key,str(TimeHelper.get_now_format_time()),ex=config.get_value("dependency_cache_expire",60*60))
-        dependency_cache_key = self._get_dependency_cache_key(dependency_key,cache_key)
+        dependency_cache_key = self.__get_dependency_cache_key(dependency_key,cache_key)
         redis_init.set(dependency_cache_key + "_savetime",str(TimeHelper.get_now_format_time()),ex=cache_expire)
         return redis_init.set(dependency_cache_key,JsonHelper.json_dumps(value),ex=cache_expire)
 
-    def _redis_init(self, db=None, decode_responses=True):
+    def __redis_init(self, db=None, decode_responses=True):
         """
         :description: redis初始化
         :return: redis_cli
@@ -143,8 +143,8 @@ class CacheModel(BaseModel):
         :return: 
         :last_editors: HuangJianYi
         """
-        redis_init = self._redis_init()
-        return redis_init.delete(self._get_dependency_key(dependency_key))
+        redis_init = self.__redis_init()
+        return redis_init.delete(self.__get_dependency_key(dependency_key))
 
     def get_cache_list(self, where='', group_by='', order_by='', limit='', params=None,dependency_key='', cache_expire=600):
         """
@@ -169,9 +169,9 @@ class CacheModel(BaseModel):
             limit = " LIMIT "+str(limit)
         sql = f"SELECT * FROM {self.table_name}{where}{group_by}{order_by}{limit};"
         
-        dependency_key = self._get_dependency_key(str(dependency_key))
-        cache_key = "entitylist_" + self.table_name + "_" + self._get_cache_key(where,group_by,order_by,limit,params)
-        list_row = self._get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.__get_dependency_key(str(dependency_key))
+        cache_key = "entitylist_" + self.table_name + "_" + self.__get_cache_key(where,group_by,order_by,limit,params)
+        list_row = self.__get_dependency_cache(dependency_key,cache_key)
         if list_row and config.get_value("is_redis_cache",True) == True:
             if list_row == 'null':
                 return None    
@@ -181,7 +181,7 @@ class CacheModel(BaseModel):
             cache_value = deepcopy(list_row)
             if not cache_value:
                 cache_value = None
-            self._set_dependency_cache(dependency_key,cache_key,cache_value,cache_expire)
+            self.__set_dependency_cache(dependency_key,cache_key,cache_value,cache_expire)
             return self._BaseModel__row_entity_list(list_row)
 
     def get_cache_page_list(self, field="*", page_index=0, page_size=20, where='', group_by='', order_by='', params=None, dependency_key='', cache_expire=600):
@@ -210,9 +210,9 @@ class CacheModel(BaseModel):
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {limit};"
         count_sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by};"
         
-        dependency_key = self._get_dependency_key(str(dependency_key))
-        cache_key = "entitypagelist_" + self.table_name + "_" + self._get_cache_key(where,group_by,order_by,limit,params)
-        page_list = self._get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.__get_dependency_key(str(dependency_key))
+        cache_key = "entitypagelist_" + self.table_name + "_" + self.__get_cache_key(where,group_by,order_by,limit,params)
+        page_list = self.__get_dependency_cache(dependency_key,cache_key)
         if page_list and config.get_value("is_redis_cache",True) == True:
             return self._BaseModel__row_entity_list(page_list["data"]),page_list["row_count"]
         else:
@@ -225,7 +225,7 @@ class CacheModel(BaseModel):
             page_list = {}
             page_list["data"] = list_row
             page_list["row_count"] = row_count
-            self._set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
+            self.__set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
             return self._BaseModel__row_entity_list(page_list["data"]), row_count
             
     def get_cache_entity(self, where='', group_by='', order_by='',  params=None, dependency_key='', cache_expire=600):
@@ -248,16 +248,16 @@ class CacheModel(BaseModel):
             order_by = " ORDER BY " + order_by
         sql = f"SELECT * FROM {self.table_name}{where}{group_by}{order_by} LIMIT 1;"
 
-        dependency_key = self._get_dependency_key(str(dependency_key))
-        cache_key = "entity_" + self.table_name + "_" + self._get_cache_key(where,group_by,order_by,'1',params)
-        one_row = self._get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.__get_dependency_key(str(dependency_key))
+        cache_key = "entity_" + self.table_name + "_" + self.__get_cache_key(where,group_by,order_by,'1',params)
+        one_row = self.__get_dependency_cache(dependency_key,cache_key)
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
                 return None    
             return self._BaseModel__row_entity(one_row)
         else:
             one_row = self.db.fetch_one_row(sql, params)
-            self._set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
+            self.__set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
             return self._BaseModel__row_entity(one_row)
 
     def get_cache_entity_by_id(self, primary_key_id, dependency_key='', cache_expire=600):
@@ -273,16 +273,16 @@ class CacheModel(BaseModel):
         params = [primary_key_id]
         sql = f"SELECT * FROM {self.table_name} WHERE {where};"
  
-        dependency_key = self._get_dependency_key(str(dependency_key))
-        cache_key = "entityone_" + self.table_name + "_" + self._get_cache_key(where,'','','',params)
-        one_row = self._get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.__get_dependency_key(str(dependency_key))
+        cache_key = "entityone_" + self.table_name + "_" + self.__get_cache_key(where,'','','',params)
+        one_row = self.__get_dependency_cache(dependency_key,cache_key)
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
                 return None 
             return self._BaseModel__row_entity(one_row)
         else:
             one_row = self.db.fetch_one_row(sql,params)
-            self._set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
+            self.__set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
             return self._BaseModel__row_entity(one_row)
 
     def get_cache_total(self, where='', group_by='', field=None, params=None,dependency_key='', cache_expire=600):
@@ -305,9 +305,9 @@ class CacheModel(BaseModel):
             field = self.primary_key_field
         sql = f"SELECT COUNT({field}) AS count FROM {self.table_name}{where}{group_by};"
 
-        dependency_key = self._get_dependency_key(str(dependency_key))
-        cache_key = "total_" + self.table_name + "_" + self._get_cache_key(where,group_by,'','',params)
-        total = self._get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.__get_dependency_key(str(dependency_key))
+        cache_key = "total_" + self.table_name + "_" + self.__get_cache_key(where,group_by,'','',params)
+        total = self.__get_dependency_cache(dependency_key,cache_key)
         if total and config.get_value("is_redis_cache",True) == True:
             if total == '0':
                 return 0
@@ -316,7 +316,7 @@ class CacheModel(BaseModel):
         else:
             list_row = self.db.fetch_one_row(sql, params)
             if list_row and 'count' in list_row:
-                self._set_dependency_cache(dependency_key,cache_key,list_row['count'],cache_expire)
+                self.__set_dependency_cache(dependency_key,cache_key,list_row['count'],cache_expire)
                 return list_row['count']
             return 0
 
@@ -346,9 +346,9 @@ class CacheModel(BaseModel):
             limit = " LIMIT "+str(limit)
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit}"
 
-        dependency_key = self._get_dependency_key(str(dependency_key))
-        cache_key = "dict_" + self.table_name + "_" + self._get_cache_key(where,group_by,order_by,limit,params)
-        one_row = self._get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.__get_dependency_key(str(dependency_key))
+        cache_key = "dict_" + self.table_name + "_" + self.__get_cache_key(where,group_by,order_by,limit,params)
+        one_row = self.__get_dependency_cache(dependency_key,cache_key)
         
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
@@ -356,7 +356,7 @@ class CacheModel(BaseModel):
             return one_row
         else:
             one_row = self.db.fetch_one_row(sql, params)
-            self._set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
+            self.__set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
             return one_row
 
     def get_cache_dict_by_id(self, primary_key_id, dependency_key='', cache_expire=600, field="*"):
@@ -373,16 +373,16 @@ class CacheModel(BaseModel):
         params = [primary_key_id]
         sql = f"SELECT {field} FROM {self.table_name} WHERE {where};"
 
-        dependency_key = self._get_dependency_key(str(dependency_key))
-        cache_key = "dictone_" + self.table_name + "_" + self._get_cache_key(where,'','','',params)
-        one_row = self._get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.__get_dependency_key(str(dependency_key))
+        cache_key = "dictone_" + self.table_name + "_" + self.__get_cache_key(where,'','','',params)
+        one_row = self.__get_dependency_cache(dependency_key,cache_key)
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
                 return None    
             return one_row
         else:
             one_row = self.db.fetch_one_row(sql,params)
-            self._set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
+            self.__set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
             return one_row
 
     def get_cache_dict_list(self, where='', group_by='', order_by='', limit='', field="*", params=None, dependency_key='',cache_expire=600):
@@ -409,14 +409,14 @@ class CacheModel(BaseModel):
             limit = " LIMIT "+str(limit)
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit};"
 
-        dependency_key = self._get_dependency_key(str(dependency_key))
-        cache_key = "dictlist_" + self.table_name + "_" + self._get_cache_key(where,group_by,order_by,limit,params)
-        list = self._get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.__get_dependency_key(str(dependency_key))
+        cache_key = "dictlist_" + self.table_name + "_" + self.__get_cache_key(where,group_by,order_by,limit,params)
+        list = self.__get_dependency_cache(dependency_key,cache_key)
         if list and config.get_value("is_redis_cache",True) == True:
             return list
         else:
             list = self.db.fetch_all_rows(sql, params)
-            self._set_dependency_cache(dependency_key,cache_key,list,cache_expire)
+            self.__set_dependency_cache(dependency_key,cache_key,list,cache_expire)
             return list
 
     def get_cache_dict_page_list(self, field="*", page_index=0 ,page_size=20, where='', group_by='' ,order_by='' ,params=None, dependency_key='', cache_expire=600):
@@ -444,9 +444,9 @@ class CacheModel(BaseModel):
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {limit}"
         count_sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by};"
    
-        dependency_key = self._get_dependency_key(str(dependency_key))
-        cache_key = "dictpagelist_" + self.table_name + "_" + self._get_cache_key(where,group_by,order_by,limit,params)
-        page_list = self._get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.__get_dependency_key(str(dependency_key))
+        cache_key = "dictpagelist_" + self.table_name + "_" + self.__get_cache_key(where,group_by,order_by,limit,params)
+        page_list = self.__get_dependency_cache(dependency_key,cache_key)
         if page_list and config.get_value("is_redis_cache",True) == True:
             return page_list["data"],page_list["row_count"]
         else:
@@ -459,5 +459,5 @@ class CacheModel(BaseModel):
             page_list = {}
             page_list["data"] = list_row
             page_list["row_count"] = row_count
-            self._set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
+            self.__set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
             return list_row, row_count
