@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-05 10:54:36
-@LastEditTime: 2021-09-07 14:49:20
+@LastEditTime: 2021-09-18 11:49:54
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -57,7 +57,7 @@ class ModuleBaseModel():
                 return None
         return act_module_dict
 
-    def get_act_module_list(self,app_id,act_id,module_name,start_date,end_date,is_del,page_size,page_index,is_cache=True):
+    def get_act_module_list(self,app_id,act_id,module_name,start_date,end_date,is_del,page_size,page_index,order_by="sort_index desc,id asc",condition="",params=[],is_cache=True):
         """
         :description: 获取活动信息列表
         :param app_id: 应用标识
@@ -68,29 +68,34 @@ class ModuleBaseModel():
         :param is_del: 是否回收站1是0否
         :param page_size: 条数
         :param page_index: 页数
+        :param order_by：排序
+        :param condition：条件
+        :param params：参数化数组
         :param is_cache: 是否缓存
         :return: 
         :last_editors: HuangJianYi
         """
-        order_by = "sort_index desc,id asc"
-        condition = "app_id=%s and act_id=%s"
-        params = [app_id,act_id]
+        where = "app_id=%s AND act_id=%s"
+        params_list = [app_id,act_id]
+        if condition:
+            where += " AND " + condition
+            params_list.extend(params)
         if is_del !=-1:
-            condition += " and is_del=%s"
-            params.append(is_del)
+            where += " AND is_del=%s"
+            params_list.append(is_del)
         if module_name:
-            condition += " and module_name=%s"
-            params.append(module_name)
+            where += " AND module_name=%s"
+            params_list.append(module_name)
         if start_date != "":
-            condition += " and start_date>=%s"
-            params.append(start_date)
+            where += " AND start_date>=%s"
+            params_list.append(start_date)
         if end_date != "":
-            condition += " and end_date<=%s"
-            params.append(end_date)
+            where += " AND end_date<=%s"
+            params_list.append(end_date)
         if is_cache:
-            page_list, total = ActModuleModel(context=self.context).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params,dependency_key=f"act_module_list:actid_{act_id}")
+            page_list, total = ActModuleModel(context=self.context).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,dependency_key=f"act_module_list:actid_{act_id}")
         else:
-            page_list, total = ActModuleModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by, params=params)    
+            page_list, total = ActModuleModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)    
         return page_list, total
 
     def save_act_module(self,app_id,act_id,module_id,module_name,module_sub_name,start_date,end_date,module_pic,module_desc,price,price_gear_id,ip_id,join_ways,is_fictitious,sort_index,is_release,i1,i2,i3,i4,i5,s1,s2,s3,s4,s5,d1,d2):
@@ -128,7 +133,7 @@ class ModuleBaseModel():
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if not app_id or not act_id:
+        if not act_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
@@ -214,7 +219,7 @@ class ModuleBaseModel():
         is_release = 0 if is_del == 1 else 1
         modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = act_module_model.update_table("is_del=%s,is_release=%s,release_date=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, modify_date, module_id])
-        self._delete_act_module_dependency_key(act_module_dict.act_id,module_id)
+        self._delete_act_module_dependency_key(act_module_dict["act_id"],module_id)
         return invoke_result_data
     
     def release_act_module(self,app_id,module_id,is_release):
@@ -235,7 +240,7 @@ class ModuleBaseModel():
             invoke_result_data.error_message = "活动信息不存在"
             return invoke_result_data
         invoke_result_data.success = act_module_model.update_table("release_date=%s,is_release=%s", "id=%s", [SevenHelper.get_now_datetime(), is_release, module_id])
-        self._delete_act_module_dependency_key(act_module_dict.act_id,module_id)
+        self._delete_act_module_dependency_key(act_module_dict["act_id"],module_id)
         return invoke_result_data
     
     def update_act_module_price(self,app_id,act_id,prize_gear_id):
