@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2021-09-10 17:14:30
+@LastEditTime: 2021-09-27 11:28:25
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -216,29 +216,35 @@ class OrderBaseModel(FrameBaseModel):
         prize_order_model.update_table("seller_remark=%s,modify_date=%s", "id=%s", [seller_remark, now_datetime, prize_order_id])
         return invoke_result_data
 
-    def import_prize_order(self,app_id,act_id,content,ref_head_name='小程序订单号'):
+    def import_prize_order(self,app_id,act_id,content_type,content,ref_head_name='小程序订单号'):
         """
         :description: 
         :param app_id：应用标识
         :param act_id：活动标识
-        :param content：base64加密后的excel内容
+        :param content_type：内容类型 1-base64字符串内容 2-json字符串内容
+        :param content：字符串内容
         :param ref_head_name：关联表头名称
         :return 
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if not app_id or not act_id:
+        if not act_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="无效活动,无法导入订单"
             return invoke_result_data
-
-        data = base64.decodebytes(content.encode())
-        path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
-        with open(path, 'ba') as f:
-            buf = bytearray(data)
-            f.write(buf)
-        f.close()
+        data = []   
+        if content_type == 1:
+            data = base64.decodebytes(content.encode())
+            if not os.path.exists("temp"):
+                os.makedirs("temp")
+            path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
+            with open(path, 'ba') as f:
+                buf = bytearray(data)
+                f.write(buf)
+            f.close()
+        else:
+            data = SevenHelper.json_loads(content.decode())
 
         order_no_index = -1
         express_no_index = -1
@@ -300,7 +306,7 @@ class OrderBaseModel(FrameBaseModel):
         params = [app_id,act_id]
         page_info = PageInfo(page_index, page_size, 0, [])
         
-        if not app_id or not act_id:
+        if not act_id:
             return page_info
         if not user_id and not open_id:
             return page_info
@@ -342,7 +348,7 @@ class OrderBaseModel(FrameBaseModel):
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if not app_id or not act_id:
+        if not act_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message ="无效活动,无法创建订单"
@@ -686,59 +692,60 @@ class OrderBaseModel(FrameBaseModel):
         :return: PageInfo
         :last_editors: HuangJianYi
         """
+        where = "app_id=%s AND act_id=%s"
+        params_list = [app_id,act_id]
         if condition:
-            condition+=" AND "     
-        condition += "app_id=%s and act_id=%s"
-        params.extend([app_id,act_id])
+            where += " AND " + condition
+            params_list.extend(params)
         page_info = PageInfo(page_index, page_size, 0, [])
         
         if not app_id or not act_id:
             return page_info
         if module_id:
-            condition += " AND module_id=%s"
-            params.append(module_id)
+            where += " AND module_id=%s"
+            params_list.append(module_id)
         if user_id:
-            condition += " AND user_id=%s"
-            params.append(user_id)
+            where += " AND user_id=%s"
+            params_list.append(user_id)
         if open_id:
-            condition += " AND open_id=%s"
-            params.append(open_id)
+            where += " AND open_id=%s"
+            params_list.append(open_id)
         if user_nick:
-            condition += " AND user_nick=%s"
-            params.append(user_nick)
+            where += " AND user_nick=%s"
+            params_list.append(user_nick)
         if order_no:
-            condition += " AND order_no=%s"
-            params.append(order_no)
+            where += " AND order_no=%s"
+            params_list.append(order_no)
         if goods_type !=-1:
-            condition += " AND goods_type=%s"
-            params.append(goods_type)
+            where += " AND goods_type=%s"
+            params_list.append(goods_type)
         if prize_type !=-1:
-            condition += " AND prize_type=%s"
-            params.append(prize_type)
+            where += " AND prize_type=%s"
+            params_list.append(prize_type)
         if logistics_status !=-1:
-            condition += " AND logistics_status=%s"
-            params.append(logistics_status)
+            where += " AND logistics_status=%s"
+            params_list.append(logistics_status)
         if prize_status !=-1:
-            condition += " AND prize_status=%s"
-            params.append(prize_status)
+            where += " AND prize_status=%s"
+            params_list.append(prize_status)
         if pay_status !=-1:
-            condition += " AND pay_status=%s"
-            params.append(pay_status)
+            where += " AND pay_status=%s"
+            params_list.append(pay_status)
         if create_date_start:
-            condition += " AND create_date>=%s"
-            params.append(create_date_start)
+            where += " AND create_date>=%s"
+            params_list.append(create_date_start)
         if create_date_end:
-            condition += " AND create_date<=%s"
-            params.append(create_date_end)
+            where += " AND create_date<=%s"
+            params_list.append(create_date_end)
         
         prize_roster_model = PrizeRosterModel(context=self.context)
         if is_cache:
             dependency_key = f"prize_roster_list:actid_{act_id}"
             if user_id:
                     dependency_key += f"_userid_{user_id}"
-            page_list, total = prize_roster_model.get_cache_dict_page_list(field, page_index, page_size, condition, "", order_by, params,dependency_key)
+            page_list, total = prize_roster_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list,dependency_key)
         else:
-            page_list, total = prize_roster_model.get_dict_page_list(field, page_index, page_size, condition, "", order_by, params)
+            page_list, total = prize_roster_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list)
         page_info = PageInfo(page_index, page_size, total, page_list)
         return page_info
 
