@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2021-09-08 19:18:22
+@LastEditTime: 2021-09-17 20:11:00
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -141,7 +141,7 @@ class PrizeBaseModel():
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
-        if not app_id or (not module_id and not act_id):
+        if not module_id and not act_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
