@@ -2,23 +2,24 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2021-09-08 10:59:44
+@LastEditTime: 2021-09-10 13:37:17
 @LastEditors: HuangJianYi
 @Description: 
 """
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
-
+from seven_cloudapp_frame.models.frame_base_model import FrameBaseModel
 from seven_cloudapp_frame.models.db_models.stat.stat_queue_model import *
 from seven_cloudapp_frame.models.db_models.stat.stat_report_model import *
 from seven_cloudapp_frame.models.db_models.stat.stat_orm_model import *
 
-class StatBaseModel():
+class StatBaseModel(FrameBaseModel):
     """
     :description: 统计上报业务模型
     """
     def __init__(self, context):
         self.context = context
+        super(StatBaseModel,self).__init__(context)
 
     def add_stat(self, app_id, act_id, module_id, user_id, open_id, key_name, key_value):
         """
@@ -123,6 +124,7 @@ class StatBaseModel():
             for orm in orm_list:
                 data = {}
                 data["title"] = orm.key_value
+                data["name"] = orm.key_name
                 data["value"] = 0
                 for behavior_report in behavior_report_list:
                     if behavior_report["key_name"] == orm.key_name:
@@ -152,6 +154,7 @@ class StatBaseModel():
                     for orm in orm_list_1:
                         data = {}
                         data["title"] = orm.key_value
+                        data["name"] = orm.key_name
                         data["value"] = 0
                         for behavior_report in behavior_report_list:
                             if behavior_report["key_name"] == orm.key_name:
@@ -215,6 +218,7 @@ class StatBaseModel():
             for orm in orm_list:
                 data = {}
                 data["title"] = orm.key_value
+                data["name"] = orm.key_name
                 data["value"] = []
                 for date_day in date_list:
                     behavior_date_report = {}
@@ -249,6 +253,7 @@ class StatBaseModel():
                     for orm in orm_list_1:
                         data = {}
                         data["title"] = orm.key_value
+                        data["name"] = orm.key_name
                         data["value"] = []
                         for date_day in date_list:
                             behavior_date_report = {}
@@ -268,4 +273,94 @@ class StatBaseModel():
 
             common_group_data_list.append(group_data)
 
-        return common_group_data_list
\ No newline at end of file
+        return common_group_data_list
+
+    def process_invite_report(self,app_id,act_id,module_id,user_id,login_token,invite_user_id,handler_name,check_user_nick=True,continue_request_expire=5):
+        """
+        :description: 处理邀请进入上报
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
+        :param invite_user_id:邀请人用户标识
+        :param handler_name:接口名称
+        :param check_user_nick:是否校验昵称为空
+        :param continue_request_expire:连续请求过期时间，为0不进行校验，单位秒
+        :return 
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        acquire_lock_name = f"process_invite_report:{act_id}_{module_id}_{user_id}"
+        identifier = ""
+        try:
+            invoke_result_data = InvokeResultData()
+            if user_id == invite_user_id:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = "无效邀请" 
+                return invoke_result_data
+            
+            invoke_result_data = self.business_process_executing(app_id,act_id,module_id,user_id,login_token,handler_name,False,check_user_nick,continue_request_expire,acquire_lock_name)
+            if invoke_result_data.success == True:
+                act_info_dict = invoke_result_data.data["act_info_dict"]
+                act_module_dict = invoke_result_data.data["act_module_dict"]
+                user_info_dict = invoke_result_data.data["user_info_dict"]
+                identifier = invoke_result_data.data["identifier"]
+
+                stat_base_model = StatBaseModel(context=self.context)
+                key_list_dict = {}
+                key_list_dict["AddBeInvitedUserCount"] = 1 #从分享进入新增用户数
+                key_list_dict["BeInvitedUserCount"] = 1 #从分享进入用户数
+                key_list_dict["BeInvitedCount"] = 1 #从分享进入次数
+                stat_base_model.add_stat_list(app_id, act_id, module_id, user_info_dict["user_id"], user_info_dict["open_id"], key_list_dict)
+            
+        except Exception as ex:
+            self.context.logging_link_error("【处理邀请上报】" + str(ex))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = "系统繁忙,请稍后再试"    
+        
+        self.business_process_executed(act_id,module_id,user_id,handler_name,acquire_lock_name,identifier)
+
+        return invoke_result_data 
+        
+    def process_share_report(self,app_id,act_id,module_id,user_id,login_token,handler_name,check_user_nick=True,continue_request_expire=5,is_stat=True):
+        """
+        :description: 处理分享上报
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
+        :param handler_name:接口名称
+        :param check_user_nick:是否校验昵称为空
+        :param continue_request_expire:连续请求过期时间，为0不进行校验，单位秒
+        :param is_stat:是否统计上报
+        :return 
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        acquire_lock_name = f"process_share_report:{act_id}_{module_id}_{user_id}"
+        identifier = ""
+        try:
+            invoke_result_data = self.business_process_executing(app_id,act_id,module_id,user_id,login_token,handler_name,False,check_user_nick,continue_request_expire,acquire_lock_name)
+            if invoke_result_data.success == True:
+                user_info_dict = invoke_result_data.data["user_info_dict"]
+                identifier = invoke_result_data.data["identifier"]
+                if is_stat == True:
+                    stat_base_model = StatBaseModel(context=self.context)
+                    key_list_dict = {}
+                    key_list_dict["ShareUserCount"] = 1 #分享用户数
+                    key_list_dict["ShareCount"] = 1 #分享次数
+                    stat_base_model.add_stat_list(app_id, act_id, module_id, user_info_dict["user_id"], user_info_dict["open_id"], key_list_dict)
+
+        except Exception as ex:
+            self.context.logging_link_error("【处理分享上报】" + str(ex))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = "系统繁忙,请稍后再试"    
+        
+        self.business_process_executed(act_id,module_id,user_id,handler_name,acquire_lock_name,identifier)
+
+        return invoke_result_data
\ No newline at end of file
