@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 15:44:04
-@LastEditTime: 2021-08-31 09:13:34
+@LastEditTime: 2021-09-07 09:35:03
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -117,7 +117,7 @@ class ThemeBaseModel():
         :param app_id：应用标识
         :param act_id：活动标识
         :param theme_id：主题标识
-        :param is_module：是否更新活动模块皮肤
+        :param is_module：是否更新活动模块皮肤 True是False否
         :return: 获取主题列表
         :last_editors: HuangJianYi
         """
@@ -140,7 +140,7 @@ class ThemeBaseModel():
         if not skin_info:
             return self.response_json_error("error", "对不起，主题没有皮肤")
         act_info_model.update_table("theme_id=%s", "id=%s", [theme_id, act_id])
-        if is_module == 1:
+        if is_module == True:
             ActModuleModel(context=self.context).update_table("skin_id=%s", "act_id=%s", [skin_info.id, act_id])
         return invoke_result_data
         
@@ -202,7 +202,7 @@ class ThemeBaseModel():
                 theme_info.is_private = 1
             theme_info.sort_index = int(theme_total) + 1
             theme_info.is_release = 1
-            theme_info.create_date = self.get_now_datetime()
+            theme_info.create_date = SevenHelper.get_now_datetime()
             theme_id = theme_info_model.add_entity(theme_info)
             if ver_no:
                 theme_ver = ThemeVer()
@@ -263,8 +263,8 @@ class ThemeBaseModel():
                 skin_info.app_id = app_id
             skin_info.sort_index = skin_info_total + 1
             skin_info.theme_id = theme_info.id
-            skin_info.create_date = self.get_now_datetime()
-            skin_info.modify_date = self.get_now_datetime()
+            skin_info.create_date = SevenHelper.get_now_datetime()
+            skin_info.modify_date = SevenHelper.get_now_datetime()
             skin_info.out_id = skin_out_id
             skin_info.theme_out_id = theme_out_id
             skin_id = skin_info_model.add_entity(skin_info)
